@@ -29,3 +29,7 @@ SELECT extname FROM pg_extension ORDER BY 1;
 -- drop non-whitelisted extension
 DROP EXTENSION plpgsql;
 SELECT extname FROM pg_extension ORDER BY 1;
+
+-- whitelisted extension with custom after-create script
+CREATE EXTENSION pg_stat_statements;
+SELECT extname FROM pg_extension ORDER BY 1;
